## A Multifactorial, Criteria-based Progressive Algorithm for Hamstring Injury Treatment

JURDAN MENDIGUCHIA \[1\], ENRIQUE MARTINEZ-RUIZ \[2\], PASCAL EDOUARD \[3,4,5\], JEAN-BENOI \[ˆ\] T MORIN \[6\],
FRANCISCO MARTINEZ-MARTINEZ \[7\], FERNANDO IDOATE \[8\], and ALBERTO MENDEZ-VILLANUEVA \[9\]

1Department of Physical Therapy, ZENTRUM Rehab and Performance Center, Baran˜ain, SPAIN; 2Chair of Sports
Traumatology, Catholic University of San Antonio, Murcia, SPAIN; \[3\] Inter-university Laboratory of Human Movement Biology
(LIBM EA), University of Lyon, University Jean Monnet, Saint Etienne, FRANCE; \[4\] Department of Clinical and Exercise
Physiology, Sports Medicine Unity, University Hospital of Saint-Etienne, Faculty of medicine, Saint-Etienne, FRANCE;
5Medical Commission, French Athletics Federation (FFA), Paris, FRANCE; 6Universite´ Coˆte d"Azur, LAMHESS, Nice,
FRANCE; \[7\] Virgin of Arrixaca University Hospital, Murcia, SPAIN; \[8\] Radiology Department, San Miguel Clinic, Pamplona,
SPAIN; and \[9\] ASPIRE Academy for Sports Excellence, Doha, QATAR

ABSTRACT

MENDIGUCHIA, J., E. MARTINEZ-RUIZ, P. EDOUARD, J.-B. MORIN, F. MARTINEZ-MARTINEZ, F. IDOATE, and

A. MENDEZVILLANUEVA. A Multifactorial, Criteria-based Progressive Algorithm for Hamstring Injury Treatment. Med. Sci. Sports

Exerc., Vol. 49, No. 7, pp. 1482–1492, 2017. Introduction: Given the prevalence of hamstring injuries in football, a rehabilitation

program that effectively promotes muscle tissue repair and functional recovery is paramount to minimize reinjury risk and optimize

player performance and availability. Purpose: This study aimed to assess the concurrent effectiveness of administering an individualized

and multifactorial criteria-based algorithm (rehabilitation algorithm \[RA\]) on hamstring injury rehabilitation in comparison with using a

general rehabilitation protocol (RP). Methods: Implementing a double-blind randomized controlled trial approach, two equal groups of

24 football players (48 total) completed either an RA group or a validated RP group 5 d after an acute hamstring injury. Results: Within 6 months

after return to sport, six hamstring reinjuries occurred in RP versus one injury in RA (relative risk = 6, 90% confidence interval = 1–35;

clinical inference: very likely beneficial effect). The average duration of return to sport was possibly quicker (effect size = 0.34 T 0.42) in

RP (23.2 T 11.7 d) compared with RA (25.5 T 7.8 d) (j13.8%, 90% confidence interval = j34.0% to 3.4%; clinical inference: possibly

small effect). At the time to return to sport, RA players showed substantially better 10-m time, maximal sprinting speed, and greater

mechanical variables related to speed (i.e., maximum theoretical speed and maximal horizontal power) than the RP. Conclusions:

Although return to sport was slower, male football players who underwent an individualized, multifactorial, criteria-based algorithm

with a performance- and primary risk factor-oriented training program from the early stages of the process markedly decreased the risk

of reinjury compared with a general protocol where long-length strength training exercises were prioritized. Key Words: HAMSTRING

INJURY, MULTIFACTORIAL HAMSTRING REHABILITATION, INDIVIDUALIZED TREATMENT, HAMSTRING ALGORITHM

amstring strain injuries are the most prevalent diag- literature indicates that nearly one out of three hamstring
nosis in football (12). Unfortunately, hamstring in- injuries will recur, mostly within the first weeks of the ath

"

# H lete

amstring strain injuries are the most prevalent diagnosis in football (12). Unfortunately, hamstring in# H jury rates in football have remained unchanged, or

have increased (12), during the last 30 yr. Hamstring injuries
account for one of the main causes of lost playing time and
result in significant performance and financial loss to teams
as a result of player unavailability (11). The available

Address for correspondence: Jurdan Mendiguchia, P.T., Department of Physical Therapy, ZENTRUM Rehab and Performance Center, Calle B Nave 23
(Polı´gono Baran˜ain), 31010 Baran˜ain, Spain; E-mail: <jurdan24@hotmail.com>.
Submitted for publication August 2016.
Accepted for publication February 2017.
Supplemental digital content is available for this article. Direct URL citations appear in the printed text and are provided in the HTML and PDF
[versions of this article on the journal_s Web site (www.acsm-msse.org).](http://www.acsm-msse.org)

0195-9131/17/4907-1482/0

MEDICINE & SCIENCE IN SPORTS & EXERCISE�
Copyright � 2017 by the American College of Sports Medicine

DOI: 10.1249/MSS.0000000000001241

literature indicates that nearly one out of three hamstring
injuries will recur, mostly within the first weeks of the athlete"s return to sport (RTS) (27). With previous injury comprising one of the most reported nonmodifiable risk factor
for hamstring injuries in football players (39), this high rate
of recurrence (9,27) fuels the debate on whether the causes
of injury are intrinsically derived from the initial injury (i.e.,
incomplete healing process) or the result of suboptimal rehabilitation. Therefore, determining the type of rehabilitation
program that most effectively promotes muscle tissue repair
and functional recovery is paramount in minimizing the risk
of reinjury and thus to increase player availability and, consequently, performance.
The structure and content of current hamstring injury rehabilitation processes are based on principles established
in the mid-20th century (14). These principles are presented
in the form of general protocols where one or two risk factors (3,28,38) are contemplated and progressed through a
rehabilitation program according to the biology of muscle
injury and repair. Presently, rehabilitation protocols (RP) for

1482

Copyright © 2017 by the American College of Sports Medicine. Unauthorized reproduction of this article is prohibited.

football players (3,38) do not appear to place a substantial
emphasis on the programming and sequencing of training
loads or on the performance-related factors (e.g., ankle stiffness and horizontal forces) that might be necessary to prepare
the player for unique sporting demands. For example, the wellknown ‘‘leg bridge’’ exercise (38) is not associated with the type
of resistance and overall workload that the players" muscletendinous system will be exposed to after they return to play.
The nature underlying hamstring injuries is accepted
as multifactorial and complex (1,23). It has been suggested
(24) that a systematic rehabilitation process (i.e., algorithm)
consisting of an ordered sequence of steps (criteria phases)
could aid in the complicated clinical decision-making procedure of a successful return to play and subsequently decrease reinjury rates. With this algorithm approach, each
phase of hamstring strain recovery depends on the outcome
of the previous step and is based on an individualized response to progress in difficulty. Furthermore, if the algorithm is able to objectively structure the content and criteria
to be met according to (i) biological tissue repair principles
(20), (ii) main injury mechanism (i.e., sprinting mechanics
(4,26), and (iii) multiple risk factors associated with hamstring strain (23,24,39), it could conceivably provide flexible
programming accounting for the specific weaknesses of each
player. This design process is not possible in a preestablished,
one-size-fits-all general protocol (3,38). In summary, the
algorithm constitutes a theoretically objective and individualized multifactorial approach to hamstring injury rehabilitation to build a solid framework. Such a framework would

allow us to obtain (i) future feedback necessary to understand
how to achieve, include, or remove the different marked
quantitative criteria and (ii) high-quality data to avoid misleading decisions and challenge dogma that underpins ‘‘usual
care’’ to subject all elements of our management strategies
to scientific scrutiny as previously suggested. (14).
Therefore, the aim of this study was to assess the concurrent
effectiveness of implementing a multifactorial, individualized,
criteria-based algorithm approach on hamstring injury rehabilitation compared with using a general RP in male football
players. The comparison will focus on three main outcomes
that directly affect daily clinical practice of any football club:
number of reinjuries, time to return to play, and sprint performance and associated mechanical outputs.

METHODS

Study Design

An equally randomized, double-blind, parallel-group, and
controlled trial approach was used in the design of this
study. Semiprofessional male football players with acute
hamstring strain injury (grade I tear) were randomly allocated to a rehabilitation algorithm (RA) group or an RP
group. The study was designed and conducted by Zentrum
Sport and Chair of Sports Traumatology of Catholic University of San Antonio. All procedures of this study were

approved by the Ethics Committee of Catholic University of
San Antonio (No. CE_1013; UCAM, Murcia, Spain), followed
the ethical guidelines of the Declaration of Helsinki, and
conformed to the recommendations of the Consolidated Stan
dards of Reporting Trials (CONSORT) statement of 2010 (35).

Patient Recruitment

In the course of two consecutive years (March 2014 to
February 2016), potential patients from football teams within
the southeast region of Spain were attracted and recruited to
partake in this study via online advertisements, mass e-mails,
and personal contacts with physicians, coaches, and physical
therapists. As a result, 70 football players (Figure 1) showed
interest in participating by contacting the study coordinator
(E.M.R.). After initial contact, potential patients engaged in a
telephone and face-to-face survey to register age, availability,
and eligibility/ineligibility criteria (suspected hamstring strain
and contraindications to the study protocol). As medical data
were to be collected before final inclusion, all patients (or
their parents/guardians if they were younger than 18 yr) were
informed of the study nature before providing their written
informed consent to participate.

Eligibility and Ineligibility Criteria

A second investigator (J.M.) determined the eligibility
and ineligibility of all contacted football players from the
information recorded during the surveys.
To be eligible, patients were required to be (i) male, older
than 16 yr of age; (ii) available to follow a rehabilitation
program; (iii) currently playing on a semiprofessional/
professional football team; and (iv) suspected of possessing a
hamstring strain injury (of noncontact etiology), which occurred during a training or match (played within the previous
4 d) and subsequently forced the player to cease activity.
The following patients were termed ineligible: (i) those
who were suspected or verified with previous hamstring
strain injuries in the same leg in the last 6 months (34); (ii)
those who suffered an extrinsic trauma to the posterior thigh,
a grade II–grade III tear, or an avulsion (36); (iii) those who
presented ongoing or chronic hip, knee, leg, ankle, foot, or
lumbopelvic injuries that required intervention by a health
professional; and (iv) those who suffered a neurological,
cardiorespiratory, or systemic disorder .

Diagnostic Confirmation

Potential patients then participated in a clinical and ultrasound examination within 4 d of the injury to confirm or
deny the suspected hamstring strain injury. Confirmation of
the injury was based on clinical examination and/or ultrasonography. If the clinical examination revealed two or
more of the following findings, with respect to the noninjured
thigh, the hamstring strain injury was confirmed: (i) localized
pain on palpation of the hamstring muscles, (ii) posterior thigh

AN ALGORITHM FOR HAMSTRING INJURY TREATMENT Medicine & Science in Sports & Exercised 1483

Copyright © 2017 by the American College of Sports Medicine. Unauthorized reproduction of this article is prohibited.

FIGURE 1—Flow diagram outlining enrollment and testing procedures.

pain without radicular symptoms and/or diminished flexibility during a passive straight leg raise, and (iii) pain and/or
weakness with resisted knee flexion at 15- measured with

a handheld dynamometer (minimum difference of 20% between legs). In addition, the verification of all hamstring
strain injuries was required by ultrasonography with the determination of the grade of severity. Only grade I (structural
muscle injury) hamstring strain injuries were included in
the study (29). Grade I hamstring strain injuries have shown
to be more frequent and prone to reinjury (9). Conversely,
those football players with less than two clinical findings
and/or a negative, a grade II–grade III, or an avulsion ultrasound finding were excluded from the study (see Figure 1).
Clinical examination and ultrasonography procedures were
performed by the same sport medicine physician (F.M.M.)

with 96 yr experience as head physician of a professional
football team and 915 yr experience as a physician in highperformance sport in Spain. In addition, a seasoned radiologist (F.I.) with 920 yr experience in elite sport analyzed
all ultrasound images. Any diagnostic discrepancy between
physicians was discussed to reach a consensus.

Randomization and Blinding

Eligible patients were then randomized into one of the
two groups: RA group or RP group. Randomization was
performed in nine blocks of six participants. To maintain
balance among the number of subjects in each group, each
block consisted of six labels (folded papers) prepared by an
independent investigator and normally distributed as three

1484 Official Journal of the American College of Sports Medicine <http://www.acsm-msse.org>

Copyright © 2017 by the American College of Sports Medicine. Unauthorized reproduction of this article is prohibited.

RA group and three RP group. This randomization process,
to which the physical therapist (E.M.R.) stayed unblinded
to provide the assigned rehabilitation program, allowed us to
stratify subjects according to six main parameters: playing
position (i.e., goalkeeper, defender, midfield, and forward),
playing status (i.e., starting or substitute), age (i.e., young

\[e24 yr\] or old \[Q25 yr\]), mechanism of injury (i.e., highspeed running or stretching), primary injured muscle (biceps
femoris, semitendinosus, and semimembranosus), and history of previous hamstring strain injury. These parameters
have previously been shown to affect RTS and reinjury rates
in football players (1,23,24,39).

Interventions

After the randomization process, 54 football players began one of the previously mentioned rehabilitation programs
(RA or RP). Six players in total (three from each group)
were removed from the study shortly after commencement
due to changing football clubs (3), traffic accident (1), and
coach"s decision (2). Accordingly, 48 football players constituted the RA and RP groups (Table 1).
Preceding the rehabilitation program, all subjects were
requested to avoid the use of drugs and to apply the rest, ice,
compression, and elevation protocol every 2 h. All subjects
began rehabilitation on the fifth day postinjury. Both rehabilitation programs (RA or RP) were performed and controlled by the same physical therapist (E.M.R.) who was not
involved in the inclusion/exclusion process or any subsequent evaluation of the patient (i.e., clinical examination,
ultrasonography, monitoring, and RTS assessments). In this
context, each patient received a unique research number
that, along with the identifying code, was stored in a secure
location for the duration of the study. This research number
ensured the concealment of group allocation to the remaining
researchers (J.M., F.M.M., F.I., two external independent
researchers, and A.M.V.). Similarly, no patient was informed
of the characteristics comprising the two rehabilitation programs (RA or RP).

TABLE 1. Baseline characteristics of patients.

RP (n = 24) RA (n = 24)

Age (yr) 22.9 T 6.0 24.0 T 4.4
Body mass (kg) 72.7 T 13.1 74.1 T 8.3
Height (m) 1.77 T 0.09 1.76 T 0.07
Playing position
Defender 9 (38) 8 (33)
Midfielder 4 (17) 4 (17)
Attacker 9 (38) 12 (50)
Goalkeeper 2 (8) 0 (0)
Playing status
Starting 22 (92) 20 (83)
Nonstarting 2 (8) 4 (17)
Injury type
Sprinting 13 (54) 13 (54)
Stretching 8 (33) 6 (25)
Other 3 (13) 2 (8)
Unknown 0 (0) 3 (13)
Previous hamstring injuries 6 (25) 5 (21)

Data are either shown as mean T SD for continuous variables or frequency and valid column
percentage (%) for categorical variables.

RP. The RP group completed a recently described protocol that emphases loading the hamstrings during lengthening actions and is accompanied by a general rehabilitation
and progressive running program (for more information about
the RP, please see Askling et al. \[3\]). Football players assigned
to RP worked on their program on a daily basis. The previously mentioned physical therapist (E.M.R.) supervised at least
four rehabilitation sessions per week (three sessions of general
rehabilitation or progressive running program and one session
of protocol emphasizing lengthening exercises) where players
were closely monitored to follow the available instructions
and guidelines provided by Askling et al. (3). When the
clinical examination showed no signs of remaining injury, as
indicated by Askling et al. (3), an independent researcher
performed the Askling H-test, consisting of performing a
straight leg raise as fast as possible to the highest point (three
trials per leg, uninjured leg tested first; no warm-up). If the
player experienced any discomfort during this voluntary
straight leg raising, they were not allowed to return to full
training extending the rehabilitation period until the H-test
was repeated (interval of 3–5 d), and insecurity was eliminated. Subsequently, a sprint running test (detailed in the
next section) was performed within 2 wk after the Askling
H-test to permit the player back to the game.
RA. The RA group performed a modified version of a
previously proposed algorithm presented by Mendiguchia
and Brughelli (24). Unlike the original algorithm (i.e., acute,
regeneration, and functional phases), the modified version
removes the acute phase because the players began the rehabilitation program at 5 d postinjury (Figure 2). Reliable,
subjective, and objective quantifiable criteria (clinical and
functional) were systematically assessed at the beginning
and end of each week by an independent researcher to determine how and when to progress a patient through each
phase of the RA program and to minimize performance bias
(28). When one or more of the criteria established for each
phase was not achieved, the player remained in the same
phase and continued with their individualized training/
treatment, adding an additional afternoon session (same content) to eventually fulfill the required criteria. The program"s
criteria and content were selected and timed according to current knowledge on the biology of muscle injury and repair (20),
the different risk factors associated with the hamstring injury
(i.e., poor flexibility, diminished strength, altered lumbopelvic
control, fatigue, etc. \[23,24,39\]), and the main mechanisms
causing the injury (sprinting or stretching) (1,40).
During the regeneration phase of the RA, football players
daily worked both legs with a single session integrating exer[cises (see Video, Supplemental Digital Content 1, http://links.](http://links.lww.com/MSS/A882)
[lww.com/MSS/A882, which demonstrates the exercises per-](http://links.lww.com/MSS/A882)
formed during the Regeneration Phase) directed at correcting
the different risk factors and mechanisms related to hamstring
injuries. During the functional phase, a 3-d block training
periodization (see Video, Supplemental Digital Content 2,
[http://links.lww.com/MSS/A883, which illustrates the exer-](http://links.lww.com/MSS/A883)
cises corresponding at each different day of the functional

AN ALGORITHM FOR HAMSTRING INJURY TREATMENT Medicine & Science in Sports & Exercised 1485

Copyright © 2017 by the American College of Sports Medicine. Unauthorized reproduction of this article is prohibited.

FIGURE 2—Criteria used to progress a football player through each phase of RA. A, Regeneration phase criteria. B, functional phase criteria.

phase) was implemented to optimize training adaptations
and minimize potential negative training interferences, for
example, day 1—sprint training, day 2—strength training,
and day 3—manual therapy, mobility, and lumbopelvic control. A minimum of three sessions of the 3-d block training
was required to allow the player to RTS. Program and activities performed during the regeneration and functional phases
are displayed in Table 2.

In addition, basic aerobic conditioning commenced when
the player was able to perform at least three sessions of running technique without any discomfort or pain in the regeneration phase. One running session was performed every 3 d

and included four sets of 5 min at a low to moderate intensity
(player rated). Later, in the functional phase, the running
session consisted of two sets of 10 min performed at moderate
to high intensity (player rated). Suspension of running sessions
was permitted in the event of moderate discomfort or pain.

Outcomes

Primary outcome measures. One of the primary
outcomes of this study was reinjury occurrence registered
during a 6-month period after the athlete"s RTS. If during
this time a possible reinjury did occur, the physician, coach,

1486 Official Journal of the American College of Sports Medicine <http://www.acsm-msse.org>

Copyright © 2017 by the American College of Sports Medicine. Unauthorized reproduction of this article is prohibited.

TABLE 2. Rehabilitation and RTS algorithm program for hamstring injury.

1, contents corresponding to the training day 1; 2, contents corresponding to the training day 2; 3, contents corresponding to the training day 3. Minimum of three blocks 1-2-3 in the
functional phase before RTS.
Reps, repetitions; BW, body weight; NMES, neuromuscular electrical stimulation.
aMild discomfort allowed during exercises execution.

AN ALGORITHM FOR HAMSTRING INJURY TREATMENT Medicine & Science in Sports & Exercised 1487

Copyright © 2017 by the American College of Sports Medicine. Unauthorized reproduction of this article is prohibited.

physical therapist, and/or football player had to immediately
contact and inform the study coordinator (E.M.R.). The sport
medicine physician (F.M.M.) would then perform a new clinical examination and ultrasonography, conducted between
2 and 5 d postinjury, the results of which were subsequently
verified by the radiologist (F.I.). The additional primary outcome of this study was the summation of time to RTS (d),
consisting of the time needed from the initial occurrence of
the injury to full participation in football team training and
availability for match selection.
Secondary outcome measures. Secondary outcomes
of this study were the effects of RA and RP on sprinting
performance and horizontal mechanical properties (stronger
determinant of field acceleration) at the time of returning to
sport after hamstring strain injury. Because hip extensors and
knee flexors play important roles in producing forward oriented
ground reaction forces (26), we hypothesized that horizontal
mechanical properties would permit an indirect evaluation of
hamstring muscle function during high speed running actions.
This evaluation would constitute a key parameter in football
performance and injury perspectives (main injury mechanism).
In conjunction with this purpose, a sprint running test
was performed when player felt ‘‘secure’’ and pain free in
the Askling H-test for RP group and when all criteria to RTS
were achieved for the RA group. The sprint running test,
which was performed within a maximum of 2 wk after returning
to sport, was conducted on a different day from the Askling
H-test or any other test performed during the functional phase.
Players were required to have not engaged in vigorous
exercise within the previous 2 d before the sprint running
test. A standardized warm-up, consisting of 5 min of lowpace (È10 kmIh \[j\]\[1\] ) running, 3 min of lower limb muscle
stretching, 5 min of sprint-specific drills, and three progressive
6-s sprints separated by 2 min of passive rest, was performed
before the test. Subjects were then allowed 5 min of free
cooldown before performing two 50-m maximal sprints, from
a standing start, performed on a natural grass field. These
sprints were separated by 6 min of passive rest and supervised by two independent researchers. Players wore their
usual football shoes and ran during similar times (i.e., same
hour), environmental conditions of temperature (22.5-C T 5.2-C
for RA group vs 20.9-C T 4.8-C for RP group), humidity
(30.4% T 15.7% for RA group vs 30.4% T 19.1% for RP
group), and wind (8.6 T 7.8 kmIh \[j\]\[1\] for RA group vs 6.5 T
7.4 kmIh \[j\]\[1\] for RP group) according to anemometer PCEAM 82 (PCE Ibe´rica, Tobarra, Albacete, Spain).
Running speed was measured during each of the two
sprints by means of a Radar Stalker ATS System (33 Hz;
Radar Sales, Minneapolis, MN), placed on a tripod 10 m
behind the subjects at a height of 1-m approximating height
of subjects" center of mass. The resultant data were subsequently analyzed using the simple field method validated
by Samozino et al. (33). Briefly, this computation method
is based on a macroscopic inverse dynamics analysis of the
center-of-mass motion. Velocity–time data are fitted by an
exponential function, after which instantaneous velocity is

derived to compute the net horizontal anteroposterior ground
reaction force (F ) and the power output in the horizontal
direction (P). Individual linear force–velocity relationships
were then extrapolated to calculate theoretical maximal force
(F0) and velocity (V0) capabilities and underlying maximum
horizontal external power output (Pmax).
Sixteen players from the RA group (21.7 T 3.7 yr, 73.0 T
8.4 kg, 1.75 T 0.07 m) and 15 from the RP group (22.1 T 5.0 yr,
73.1 T 11.0 kg, 1.76 T 0.10 m) performed the sprint running
test. The remaining players did not undergo testing due to
moving to another club or player/coach"s personal decisions.

Statistical Methods

The number of reinjuries is presented as counts and proportions. The differences in the number of reinjuries in football players allocated to the RA or RP groups are presented as
a relative risk (RR), with the risk for the RP group divided by
the risk for the RA. The uncertainty in the effectiveness of the
two rehabilitation programs on reinjury risk was calculated
using the percent chance or likelihood that the true value of the
effect was substantial (greater than the smallest clinical importance effect). To determine the magnitude of the smallest
clinical important difference or effect in terms of reinjury risk
for the current study, we used the methods previously outlined
by Hopkins et al. (18,19). In brief, for every 10 reinjured
players in one of the rehabilitation programs, there are nine
injured players in the other program. That is, 1 in 10 injuries
is due to choosing a different rehabilitation program. If
there are N players in RP and N players in RA, risk ratio =
(10 / N ) / (9 / N ) = 10 / 9 (i.e., 1.11). We therefore
assigned this value (i.e., 1.11) as the smallest clinical important effect (18,19). Probabilities of benefit and harm were
used to make a qualitative probabilistic clinical inference
about the effect in preference to a statistical inference based
in a null hypothesis test (19). Briefly, the effect was deemed
unclear when the chance of benefit was sufficiently high to
warrant use of the treatment, but the risk of harm was unacceptable. Such unclear effects were identified as those
with an odds ratio of benefit to harm of G66, a ratio that
corresponds to an effect that is borderline possibly beneficial
(25% chance of benefit) and borderline most unlikely
harmful (0.5% risk of harm). All other effects were deemed
clinically clear and expressed as the chance of the true effect
being trivial, beneficial, or harmful with the following scale:
25%–75%, possibly; 75%–95%, likely; 95%–99.5%, very
likely; and 999.5%, most likely.
Continuous variables are presented as means T SD unless
otherwise stated. Data were first log-transformed to reduce
bias arising from nonuniformity error. The standardized difference or effect size (ES, 90% confidence interval \[CI\]) in
the selected variables was calculated using the pooled baseline SD. Threshold values for Cohen ES statistics were 90.2

(small), 90.6 (moderate), and 91.2 (large) (19). Uncertainly
in the estimated of effects on days to RTS and sprinting
performance and associated mechanical outputs was expressed

1488 Official Journal of the American College of Sports Medicine <http://www.acsm-msse.org>

Copyright © 2017 by the American College of Sports Medicine. Unauthorized reproduction of this article is prohibited.

TABLE 3. Reinjury number and relative risk at 6 months after RTS by allocated group.

Protocol vs Algorithm

Protocol Algorithm Relative Risk (90% CI) Chances for Beneficial/Trivial/Harmful Clinical Inference

Reinjury number (%) 6 (25%) 1 (4%) 6 (1; 35) 95/2/3 Very likely beneficial

as 90% CI and as probabilities that the true value of the
effect was beneficial, trivial, or harmful in relation to
threshold values for benefit and harm. For those measure
ments, a threshold was 0.20 of the between-player SD in the
baseline assessment (19). Quantitative chances of beneficial/
better or detrimental/poorer effect were assessed qualitatively
as indicated previously.

RESULTS

Reinjury

The occurrence of reinjury within 6 months is displayed
in Table 3. There were substantial differences in the rate of

reinjury at 6 months between groups (Table 3).

Time to RTS

The average duration of RTS was possibly quicker (ES =
0.34 T 0.42) in the RP group (23.2 T 11.7 d) compared with
the RA group (25.5 T 7.8 d) (j13.8%, 90% CI = j34.0 to
3.4; 70%/28%/2%, possibly small effect).

Sprint Test

The RA group presented substantially improved 10-m,
top speed, V0, and Pmax performance measures compared
with the RP group (Table 4). Trivial and unclear changes
were observed 5-m and FH0 (Table 4).

DISCUSSION

The purpose of this study was to examine the effectiveness (reinjuries, time to RTS, and sprint performance) of
an individualized and multifactorial criteria-based algorithm on hamstring injury rehabilitation compared with a
general RP (which aims at loading the hamstrings during
lengthening actions as an optimal treatment after acute
hamstring injury) in football players. The main findings of
the study were that players allocated to the RA group experienced (i) substantially less reinjuries, specifically in the early

recurrences period; (ii) substantially more time in returning
to sport after injury; and (iii) substantially greater performance (i.e., 10 m and top speed) and mechanical variables
related to speed factors (V0 and Pmax) compared with the
RP group.
Our results show that the RA, integrating the temporal
sequencing of the different and multiple risk factors related to
hamstring injury with a performance oriented training program from the early stages of the process, markedly decreased
reinjury risk compared with the RP where long-length strength
training exercises are prioritized. In this way at RTS, the
player who followed the RA presented a lower risk (4%)
compared with a typical footballer with no history of previous
injury (12%–16%) (40).
The fact that the RP group, focusing on lengthening exercises, suffered six reinjuries after the athlete returned to
play (25%) contrasts the absence of those (0%) found in
a recent study with elite male and female football players
(3). This may be partly explained by the different standard of
players (professionals vs semiprofessionals in the present study)
and the shorter average time to return to football practice
reported in the current study (23 vs 28 d in the former),
impairing the maturation healing process and, consequently,
exposing players to a higher risk of recurrence. Albeit speculative, the number of relapses recorded during the first 4 wk
post-RTS in the RP lengthening-based group (data not
presented) might confirm the previously mentioned hypothesis. However, substantially longer RTS time (i.e., 51 d), after
what was defined as a ‘‘protocol of conventional exercises,’’
resulted in only one reinjury (3%) (3), casts doubts on the
direct cause–effect relationship between the earlier RTS and
the increased risk of reinjuries. In this regard, the fact that
the present study"s players in the RA group did not show the
same trend of reinjuries as the RP group suggests that the
modification of predisposing factors and/or the higher volume and intensity of the rehabilitation treatment program
(see discussion in the next paragraph) may be more important than time to RTS per se.
The percentage of reinjury in previous rehabilitation studies, mostly involving football players, varies between 0%

TABLE 4. Sprinting performance and mechanical variables (mean T SD) for RA and protocol groups and the standardized differences (with 90% confident limits) and probabilistic inferences
about the true standardized magnitude in the means between groups.

Differences Observed between RP vs RA

RP (n = 15) RA (n = 16) Standardized Differences (90% CI) MBI Qualitative Assessment

5 m (s) 1.38 T 0.10 1.35 T 0.08 j0.27 (j0.80 to 0.26) (19/0/81) Unclear
10 m (s) 2.15 T 0.15 2.08 T 0.10 j0.46 (j0.96 to 0.05) (7/0/93) Likely
Top speed (mIs \[j\]\[1\] ) 7.7 T 0.7 8.4 T 0.4 0.75 (0.29 to 1.22) (99/0/1) Very likely
V0 (mIs \[j\]\[1\] ) 8.2 T 0.9 8.9 T 0.5 0.71 (0.24 to 1.18) (99/0/1) Very likely
FH0 (NIkg \[j\]\[1\] ) 7.9 T 1.3 7.9 T 1.1 0.06 (j0.47 to 0.59) (58/0/42) Unclear
Pmax (WIkg \[j\]\[1\] ) 16.0 T 2.9 17.5 T 2.5 0.47 (j0.04 to 0.98) (94/0/6) Likely

MBI, magnitude-based inferences.

AN ALGORITHM FOR HAMSTRING INJURY TREATMENT Medicine & Science in Sports & Exercised 1489

Copyright © 2017 by the American College of Sports Medicine. Unauthorized reproduction of this article is prohibited.

and 30% (3,15,30,31,38) and is greater for grade 1 injuries
(29), which constituted 100% of the injuries in the present
study. The therapeutic approach shared by those studies was
characterized by restoring muscle function of the localized
injured area (i.e., knee flexors strength and/or flexibility)
and paying little attention to other, more remote zones believed to play an important role on hamstring muscle function (e.g., contralateral hip flexors and lumbopelvic control).
To the authors" knowledge, there is only one study available
in male football players that have undertaken a criteria-based
rehabilitation program, reporting a 12% reinjury rate within
2 months of clinical discharge (38). Our most likely explanation of why the RA of the present study induced lower
reinjury rates (4% within 6 months of clinical discharge) is
based in the intervention"s design (programming/progression)
and content (multifactorial and performance oriented) (Table 2).
The selection of content (see Video, Supplemental Digital
[Contents 1 and 2, http://links.lww.com/MSS/A882 and http://](http://links.lww.com/MSS/A882)
[links.lww.com/MSS/A883, which illustrates the exercises](http://links.lww.com/MSS/A883)
corresponding at each phase) in the RA is based on a detailed
and functional analysis of the different risk factors potentially
associated with the hamstring injury and in the main mechanism causing the injury (sprinting or lengthening actions).
Subsequently, the contents were sequenced to progress in a
step-by-step basis according to their difficulty/intensity
(e.g., weights, opposing forces, and muscle length). The
contents also take into account the current knowledge on
the biology of muscle injury and repair and verify the
procedure by means of objective criteria referring to the
localized injured area and external factors that can influence
it. For example, the choice of hamstring and gluteal strength
training exercises, important from injury and performance
perspective, was classified as hip or knee dominant (in the
case of the hamstring) to stimulate the different muscle
bellies (25). Similarly, gluteal workouts were selected
based on the length–tension profile of each exercise and
interaction with the contralateral leg to cover its different
roles during sprint (7). In regard to intensity issues,
hamstring training advanced according to progressive
tension and functional aspects associated with action
mode (isometric to eccentric to plyometric) and muscle
length, whereas gluteus workout progressed on load intensity
(weight percentage).
Another main advantage and innovative feature of the
proposed approach (beyond its individualized and multifactorial nature), compared with previous rehabilitation
studies involving football players, is that the RA program
includes adjustments of both intensity and volume of the
programs (3,15,31,38). Although any comparison with previous studies is difficult as a result of a lack of detailed

description of actual volume and intensity of the intervention undertaken, the large differences in the main outcome
(reinjury rate) in favor of the RA proposed in this study can
be related with the higher training load accomplished (see
Table 2). In this regard, the importance of the training load
conducted during the recovery process has recently been

highlighted (5). Thus, a program design involving higher
volume and intensity periodization, as found in the present
study, might result in a more appropriate stimulus to confer
enough protection during the athlete"s RTS and, consequently,
reduce the risk of reinjury. On the basis of our results, further
studies should verify whether the RA program presented here
could, at least in part, be considered as an efficient training
stimulus for secondary prevention, once the players have
returned to practice, and even as primary prevention as
physical conditioning.
Another relevant aspect inherent to any rehabilitation process refers to the injury time and, consequently, the availability and performance (sport–economic) side of player–club
binomial. Despite starting on day 5 after injury, the RTS
duration achieved in this study in both treatment formats
is comparable with that seen in previous studies involving
mainly football players (21 to 51 d) (3,15,31,38). However,
the RP, emphasizing lengthening exercises, resulted in a
possibly quicker (small effect) RTS compared with the RA,
emphasizing an individualized and multifactorial intervention. The need to achieve each of the quantitative criteria in
each of the phases and the 3-d block training periodization
(sprint, strength, manual therapy/mobility/lumbopelvic control) followed in the functional phase of the RA (minimum
three blocks) may be one of the explanations for this difference between the two treatments (Figure 2).
Finally, in addition to returning the player to sport as
safe and fast as possible, all rehabilitation processes should
strive to do so in the best possible conditions with respect to
performance. As sprint acceleration is a key component of
performance in football and constitutes the primary hamstring
injury mechanism (1,40), it was given emphasis within the
design of the algorithm rehabilitation program (Table 2). As
such, early engagement in sprinting speed factors (e.g., running technique and specific strength), which progressed into
actual sprinting (both acceleration and peak speed), resulted
in a significant volume (a minimum of,1000 m per player)
of speed training performed before clinical discharge. Earlier
hamstring rehabilitation studies systematically programming
and periodizing sprint training loads in football players are
lacking (3,38). Nevertheless, the present findings support
the pertinence of such an approach as sprint performance (i.e.,
10 and 20 m), and associated speed-related mechanical (i.e.,
V0 and Pmax) variables were greater in the RA group compared with the RP group (Table 4). However, despite the two
groups being matched by age, playing position, status,
mechanism of injury, and primary injured muscle, we cannot
exclude that sprinting speed and mechanical performance
differences were present before the injury occurred. Another
possibility, albeit speculative, could be that the observed
differences in speed-related mechanical variables might be
related with other factors. Specifically, the apprehension
of pain (32) for the injured player to produce high power
outputs during a relatively unpracticed movement (i.e.,
long sprints) throughout the rehabilitation period could
have played a role in the reduced ability to attain high

1490 Official Journal of the American College of Sports Medicine <http://www.acsm-msse.org>

Copyright © 2017 by the American College of Sports Medicine. Unauthorized reproduction of this article is prohibited.

speeds in the RP group. Future experimental work should be
conducted to evaluate the actual effectiveness of rehabilitation

programs on game-related physical performance variables
(e.g., sprinting speed).
This study has some limitations, including a small
sample size, which is a characteristic of other studies in
this area (2,34). Furthermore, our study population was
limited to semiprofessional male football players. Thus,
our findings might not necessarily apply to female football players, to other sports, or to higher-level football
players. In addition, only grade 1 injuries were investigated in the present study. Although this type of injury is
the most common, and cause the majority of days absent,
further studies are needed to determine whether the find
ings of the present study apply to higher degree hamstring
injuries. Finally, with six events in one group and one
event in the other, the relative risk of the current study
should be interpreted with caution. Thus, future studies
including more events should confirm the effectiveness of
the proposed hamstring rehabilitation process.

REFERENCES

1. Arnason A, Sigurdsson SB, Gudmundsson A, Holme I, Engebretsen L,
   Bahr R. Risk factors for injuries in football. Am J Sports Med.
   2004;32(1 Suppl):5S–16S.
1. Askling CM, Tengvar M, Tarassova O, Thorstensson A. Acute
   hamstring injuries in Swedish elite sprinters and jumpers: a prospective randomised controlled clinical trial comparing two rehabilitation protocols. Br J Sports Med. 2014;48(7):532–9.
1. Askling CM, Tengvar M, Thorstensson A. Acute hamstring injuries in Swedish elite football: a prospective randomised controlled
   clinical trial comparing two rehabilitation protocols. Br J Sports
   Med. 2013;47(15):953–9.
1. Bezodis IN, Kerwin DG, Salo AI. Lower-limb mechanics during
   the support phase of maximum-velocity sprint running. Med Sci
   Sports Exerc. 2008;40(4):707–15.
1. Blanch P, Gabbett TJ. Has the athlete trained enough to return to
   play safely? The acute:chronic workload ratio permits clinicians

"
to quantify a player s risk of subsequent injury. Br J Sports Med.
2016;50(8):471–5.
6\. Butler D. Mobilization of the Nervous System. Melbourne: Churchill
Livingstone; 1991. pp. 139.
7\. Contreras BM, Cronin JB, Schoenfeld BJ, Nates RJ, Sonmez GT.
Are all hip extension exercises created equal? Strength Cond J.
2013;35(2):17–22.
8\. Croisier JL, Ganteaume S, Binet J, Genty M, Ferret JM. Strength
imbalances and prevention of hamstring injury in professional soccer
players: a prospective study. Am J Sports Med. 2008;36(8):1469–75.
9\. de Visser HM, Reijman M, Heijboer MP, Bos PK. Risk factors of
recurrent hamstring injuries: a systematic review. Br J Sports Med.
2012;46(2):124–30.
10\. De Vos RJ, Reurink G, Goudswaard GJ, Moen MH, Weir A,
Tol JL. Clinical findings just after return to play predict hamstring
re-injury, but baseline MRI findings do not. Br J Sports Med.
2014;48(18):1377–84.
11\. Ekstrand J. Keeping your top players on the pitch: the key
to football medicine at a professional level. Br J Sports Med.
2013;47(12):723–4.
12\. Ekstrand J, Walde´n M, Ha¨gglund M. Hamstring injuries have increased by 4% annually in men"s professional football, since 2001:
a 13-year longitudinal analysis of the UEFA Elite Club injury
study. Br J Sports Med. 2016;50(12):731–7.

CONCLUSIONS

In summary, male football players who underwent an individualized, multifactorial, criteria-based algorithm, which
integrated the temporal sequencing of the different and multiple risk factors potentially related to hamstring injury with a
performance- and primary risk factor-oriented training program from the early stages of the process, markedly decreased
the risk of reinjury, improved sprint performance and mechanical properties, but resulted in a possibly slower (small
effect) RTS compared with a general protocol where longlength strength training exercises were prioritized.

This study was made possible by technical support from the UCAM
Research Center of High Performance Sport, San Antonio Catholic
University of Murcia. The authors are especially grateful to the players
and staff of all participating teams for their attitude and collaboration.
The authors report no conflict of interest. There was no internal or
external funding in support of this project. The results of the present
study do not constitute endorsement by the American College of
Sports Medicine and are presented clearly, honestly, and without
fabrication, falsification, or inappropriate data manipulation.

13. Freckleton G, Cook J, Pizzari T. The predictive validity of a single
    leg bridge test for hamstring injuries in Australian Rules Football
    Players. Br J Sports Med. 2014;48(8):713–7.
01. Hamilton B. Hamstring muscle strain injuries: what can we learn
    from history? Br J Sports Med. 2012;46(13):900–3.
01. Hamilton B, Tol JL, Almusa E, et al. Platelet-rich plasma does not
    enhance return to play in hamstring injuries: a randomised controlled trial. Br J Sports Med. 2015;49(14):943–50.
01. Hamilton RT, Shultz SJ, Schmitz RJ, Perrin DH. Triple-hop distance as a valid predictor of lower limb strength and power. J Athl
    Train. 2008;43(2):144–51.
01. Harvey D. Assessment of the flexibility of elite athletes using the
    modified Thomas test. Br J Sports Med. 1998;32(1):68–70.
01. Hopkins WG, Batterham AM. Error rates, decisive outcomes
    and publication bias with several inferential methods. Sports Med.
    2016;46:1563–73.
01. Hopkins WG, Marshall SW, Batterham AM, Hanin J. Progressive
    statistics for studies in sports medicine and exercise science. Med
    Sci Sports Exerc. 2009;41(1):3–13.
01. Ja¨rvinen TA, Ja¨rvinen M, Kalimo H. Regeneration of injured
    skeletal muscle after the injury. Muscles Ligaments Tendons J.
    2014;3(4):337–45.
01. Kelln BM, McKeon PO, Gontkof LM, Hertel J. Hand-held
    dynamometry: reliability of lower extremity muscle testing in
    healthy, physically active, young adults. J Sport Rehabil.
    2008;17(2):160–70.
01. Liebenson C, Karpowicz AM, Brown SH, Howarth SJ, McGill
    SM. The active straight leg raise test and lumbar spine stability.
    PM R. 2009;1(6):530–5.
01. Mendiguchia J, Alentorn-Geli E, Brughelli M. Hamstring strain
    injuries: are we heading in the right direction? Br J Sports Med.
    2012;46(2):81–5.
01. Mendiguchia J, Brughelli M. A return-to-sport algorithm for acute
    hamstring injuries. Phys Ther Sport. 2011;12(1):2–14.
01. Mendiguchia J, Garrues MA, Cronin JB, et al. Nonuniform changes
    in MRI measurements of the thigh muscles after two hamstring
    strengthening exercises. J Strength Cond Res. 2013;27(3):574–81.
01. Morin JB, Gimenez P, Edouard P, et al. Sprint acceleration mechanics: the major role of hamstrings in horizontal force production. Front Physiol. 2015;6:404.

AN ALGORITHM FOR HAMSTRING INJURY TREATMENT Medicine & Science in Sports & Exercised 1491

Copyright © 2017 by the American College of Sports Medicine. Unauthorized reproduction of this article is prohibited.

27. Orchard J, Best TM. The management of muscle strain injuries: an early
    return versus the risk of recurrence. Clin J Sport Med. 2002;12(1):3–5.

01. Pas HI, Reurink G, Tol JL, Weir A, Winters M, Moen MH. Efficacy of rehabilitation (lengthening) exercises, platelet-rich plasma
    injections, and other conservative interventions in acute hamstring
    injuries: an updated systematic review and meta-analysis. Br J
    Sports Med. 2015;49(18):1197–205.

01. Peetrons P. Ultrasound of muscles. Eur Radiol. 2002;12(1):35–43.

01. Reurink G, Almusa E, Goudswaard GJ, et al. No association
    between fibrosis on magnetic resonance imaging at return to play
    and hamstring reinjury risk. Am J Sports Med. 2015;43(5):1228–34.

01. Reurink G, Goudswaard GJ, Oomen HG, et al. Reliability of the
    active and passive knee extension test in acute hamstring injuries.
    Am J Sports Med. 2013;41(8):1757–61.

01. Robinson ME, Dannecker EA. Critical issues in the use of muscle testing
    for the determination of sincerity of effort. Clin J Pain. 2004;20(6):392–8.

01. Samozino P, Rabita G, Dorel S, et al. A simple method for measuring power, force, velocity properties, and mechanical effectiveness in sprint running. Scand J Med Sci Sports. 2016;26(6):648–58.

01. Sanfilippo JL, Silder A, Sherry MA, Tuite MJ, Heiderscheit BC.
    Hamstring strength and morphology progression after return to
    sport from injury. Med Sci Sports Exerc. 2013;45(3):448–54.

01. Schulz KF, Altman DG, Moher D. CONSORT 2010 statement:
    updated guidelines for reporting parallel group randomised trials.
    J Pharmacol Pharmacother. 2010;1(12):100–7.

01. Silder A, Thelen DG, Heiderscheit BC. Effects of prior hamstring
    strain injury on strength, flexibility, and running mechanics. Clin
    Biomech (Bristol, Avon). 2010;25(7):681–6.

01. Thorborg K, Roos EM, Bartels EM, Petersen J, Ho¨lmich P. Validity, reliability and responsiveness of patient-reported outcome
    questionnaires when assessing hip and groin disability: a systematic review. Br J Sports Med. 2010;44(16):1186–96.

01. Tol JL, Hamilton B, Eirale C, Muxart P, Jacobsen P, Whiteley R.
    At return to play following hamstring injury the majority of professional football players have residual isokinetic deficits. Br J
    Sports Med. 2014;48(18):1364–9.

01. van Beijsterveldt AM, van de Port IG, Vereijken AJ, Backx FJ.
    Risk factors for hamstring injuries in male soccer players: a systematic review of prospective studies. Scand J Med Sci Sports.
    2013;23(3):253–62.

01. Woods C, Hawkins RD, Maltby S, Hulse M, Thomas A, Hodson
    A. The Football Association Medical Research Programme: an
    audit of injuries in professional football—analysis of hamstring
    injuries. Br J Sports Med. 2004;38(1):36–41.

1492 Official Journal of the American College of Sports Medicine <http://www.acsm-msse.org>

Copyright © 2017 by the American College of Sports Medicine. Unauthorized reproduction of this article is prohibited.
